CANAlization: Control & Redundancy in Boolean Networks
=======================================================

This package implements a series of methods used to study control, canalization and redundancy in Boolean Networks.

Instalation:
-------------

This package (will be) available in Pypi. Just run the following command on terminal to install.

```
    $ pip install cana
```

You can also source the code directly from the github [project page](https://github.com/rionbr/CANA).

Docs:
-------

The full documentation can be found at: [rionbr.github.io/CANA](https://rionbr.github.io/CANA)

Papers:
---------

- R.B. Correia, A. Gates, X. Wang and L.M. Rocha [2018]. "CANA: A python package for quantifying control and canalization in Boolean Networks." *In Preparation*.

- A. Gates and L.M. Rocha. [2016] "[Control of complex networks requires both structure and dynamics.](http://www.informatics.indiana.edu/rocha/publications/NSR16.php)" *Scientific Reports* **6**, 24456. doi: 10.1038/srep24456.

- A. Gates and L.M. Rocha [2014]. "[Structure and dynamics affect the controllability of complex systems: a Preliminary Study](http://www.informatics.indiana.edu/rocha/publications/alife14a.html)". *Artificial Life 14: Proceedings of the Fourteenth International Conference on the Synthesis and Simulation of Living Systems*: 429-430, MIT Press.

- M. Marques-Pita and L.M. Rocha [2013]. "[Canalization and control in automata networks: body segmentation in Drosophila Melanogaster](http://informatics.indiana.edu/rocha/publications/plos2012.html)". *PLoS ONE*, **8**(3): e55946. doi:10.1371/journal.pone.0055946.



